# Stormy Seas
## Description
This game is a classic 2d obstacle game. The game is written in Python Pygame library, so dont expect miracles. <br>
The gameplay is very simple, there is obstacles like rooks and icebergs coming from the top of the screen, and player has to avoid them. <br>
Features: Game has many basic features such as a settings menu, main menu, etc. It also has basic enemies, it is also resizable and should work in any window size. <br>
## Controls
W,UP_arrow = forwards movement <br>
S,DOWN_arrow = backwards movement <br>
A, LEFT_arow = turn left(angle) <br>
D, RIGHT_arrow turn right(angle) <br>
SPACE = shoot <br>
R = restart game <br>
## Screenshots of the game 
<br>
<br>
## Why this ?
The reasons are pretty simple. I had last programmed in Python a few months ago, so I needed some simple project to relearn it, and the HackClub event this project is tied to has a pirat theme, so it was clear what I will do. <br>

<h1>Download instructions</h1>
*Note the links are instructional images <br>
**Note the images used bellow are from a different Github repository, however the overall procces is allways the same. <br>
<h2>Using graphic UI</h2>
<h3>Downloading EXE <h3>
First make sure you have the latest release version selected <br>
(https://github.com/user-attachments/assets/7a3fbbd6-9fa7-4034-80e2-32c5c181ac79) <br>
Then click on download exe file and wait until it downloads <br>
(https://github.com/user-attachments/assets/dc9c87e7-6e18-4a91-a9d5-a8f908b2d6c7) <br>
After its downloaded you can find it through file explorer or the browser it self. <br>
Enjoy!<br>
<h3>Downloading source code <h3>
First click on the code button as shown in the picture bellow, then click the option Download ZIP <br>
(https://github.com/user-attachments/assets/801a8deb-b6e5-475e-9b6b-262b56fd6a23) <br>
After its downloaded you can find it on your computer through file explorer. After you have found it right click it, it should display option called "Extract" <br>
Click on it and wait a moment. A new directory should appear containing all the files neccesary for the game.<br>
Now open a console and enter the folowing code: pip install -r /path/to/requirements.txt <br>
*Replace the /path/to/requirements.txt with the actual path. <br>
Enjoy the game! <br>
<h2>Using command prompt</h2>
<h3>Downloading source code <h3>
Open your command prompt and enter the folowing code without the " letters <br>
"git clone https://github.com/Daniel908009/Stormy-Seas.git" <br>
This code adress of the site can also be found if you click the code button inside the github repository UI <br>
If you dont have git than first enter the folowing command: sudo apt install git <br>
Now open a console and enter the folowing code: pip install -r /path/to/requirements.txt <br>
*Replace the /path/to/requirements.txt with the actual path. <br>
Enjoy the game! <br>